/*
 * edu.calstatela.curvebank.goodstein.GoodsteinTableModel
 * Goodstein Sequence Applet
 * 
 * Created January 2, 2004
 * 
 * Send any comments or bug fixes to the author at matthew.nelson@acm.org.
 * 
 * Copyright (c) 2004 Matthew Nelson. All Rights Reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   1. Redistributions of source code must retain the above copyright notice,
 *      this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 *      derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package edu.calstatela.curvebank.goodstein;

import javax.swing.table.AbstractTableModel;
import java.util.ArrayList;

/**
 * Serves {@link Applet} by storing the elements of a Goodstein sequence.
 * This class uses less memory than <code>DefaultTableModel</code>. 
 * 
 * @author Matthew Nelson
 */
class GoodsteinTableModel extends AbstractTableModel {

	private int initialBase = 2;
	private ArrayList numberData = new ArrayList();
	private ArrayList superbaseData = new ArrayList();
	
	public void clear() {
		numberData.clear();
		superbaseData.clear();
		
		// Fire event
		fireTableDataChanged();
	}
	
	public void setInitialBase(int base) {
		initialBase = base;
	}
	
	public void addRow(Object number, Object superbase) {
		numberData.add(number);
		superbaseData.add(superbase);
		
		// Fire event
		fireTableRowsInserted(numberData.size()-1, numberData.size()-1);
	}

	/*
	 * @see javax.swing.table.TableModel#getColumnName(int)
	 */
	public String getColumnName(int column) {
		switch (column) {
			case 0: return "Step";
			case 1: return "Base";
			case 2: return "Number";
			case 3: return "Superbase";
			default: return null;
		}
	}

	/*
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	public int getColumnCount() {
		return 4;
	}

	/*
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return numberData.size();
	}

	/*
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		if (rowIndex >= numberData.size()) {
			return null;
		}
		switch (columnIndex) {
			case 0: return new Integer(rowIndex);
			case 1: return new Integer(rowIndex + initialBase);
			case 2: return numberData.get(rowIndex);
			case 3: return superbaseData.get(rowIndex);
		}
		return null;
	}

}
